@@ -1,4 +1,5 @@
 import asyncio
+import warnings
 from dataclasses import asdict
 from datetime import datetime, timedelta
 from json import dumps as convert_obj_to_json
@@ -10,15 +11,18 @@ import aiohttp
 
 from .constants import ratelimit_data, routes
 from .enum import ContentRating, Demographic, MangaStatus, TagMode
-from .exceptions import InvalidID, Ratelimit, Unauthorized
+from .exceptions import Captcha, InvalidCaptcha, InvalidID, Ratelimit, Unauthorized
 from .list_orders import AuthorListOrder, ChapterListOrder, GroupListOrder, MangaListOrder
 from .models.abc import Model
 from .models.author import Author
 from .models.chapter import Chapter
+from .models.client_user import ClientUser
+from .models.custom_list import CustomList
 from .models.group import Group
-from .models.manga import Manga
+from .models.manga import Manga, MangaLinks
 from .models.pager import Pager
 from .models.tag import Tag, TagDict
+from .models.title import TitleList
 from .models.user import User
 from .ratelimit import Ratelimits
 from .utils import remove_prefix, return_date_string
@@ -102,6 +106,12 @@ class MangadexClient:
     .. versionadded:: 0.2
     """
 
+    user: ClientUser
+    """The user of the client.
+    
+    .. versionadded:: 0.5
+    """
+
     # Dunder methods
 
     def __init__(
@@ -129,6 +139,7 @@ class MangadexClient:
             self.username = self.password = self.refresh_token = None
         self.ratelimits = Ratelimits(*ratelimit_data)
         self.tag_cache = TagDict()
+        self.user = ClientUser(self)
         self._request_count = 0
         self._request_second_start = datetime.utcnow()  # Use utcnow to keep everything using UTF+0 and also helps
         # with daylight savings.
@@ -170,6 +181,7 @@ class MangadexClient:
         json: Any = None,
         with_auth: bool = True,
         retries: int = 3,
+        allow_non_successful_codes: bool = False,
         **session_request_kwargs,
     ) -> aiohttp.ClientResponse:
         """Perform a request.
@@ -206,9 +218,14 @@ class MangadexClient:
         :param retries: The amount of times to retry. The function will recursively call itself, subtracting ``1``
             from the original count until retries run out.
         :type retries: int
+        :param allow_non_successful_codes: Whether or not to allow non-success codes (4xx codes that aren't 401/429)
+            to pass through instead of raising an error. False by default
+        :type allow_non_successful_codes: bool
         :param session_request_kwargs: Optional keyword arguments to pass to :meth:`aiohttp.ClientSession.request`.
         :raises: :class:`.Unauthorized` if the endpoint requires authentication and sufficient parameters for
             authentication were not provided to the client.
+        :raises: :class`aiohttp.ClientResponseError` if the response is a 4xx or 5xx code after multiple retries or
+            if it will not be retried and ``allow_non_successful_codes`` is False.
         :return: The response.
         :rtype: aiohttp.ClientResponse
         """
@@ -231,12 +248,7 @@ class MangadexClient:
             if self.session_token is None:
                 await self.get_session_token()
             headers["Authorization"] = f"Bearer {self.session_token}"
-        if self.sleep_on_ratelimit:
-            path_obj = await self.ratelimits.sleep(remove_prefix(self.api_base, url), method)
-        else:
-            time_to_sleep, path_obj = await self.ratelimits.check(url, method)
-            if time_to_sleep > 0 and path_obj:
-                raise Ratelimit(path_obj.path.name, path_obj.ratelimit_amount, path_obj.ratelimit_expires)
+        path_obj = None
         if url.startswith(self.api_base):
             # We only want the ratelimit to only apply to the API urls.
             async with self._request_lock:
@@ -246,38 +258,54 @@ class MangadexClient:
                 time_difference = (time_now - self._request_second_start).total_seconds()
                 if time_difference <= 1.25 and self._request_count >= 5:  # Hopefully this will stop excess retries
                     # which cripple pagers.
-                    await asyncio.sleep(1)
+                    logger.warning("Sleeping for 1.25 seconds.")
+                    await asyncio.sleep(1.25)
                 elif time_difference > 1:
                     self._request_count = 0
                     self._request_second_start = time_now
+            if self.sleep_on_ratelimit:
+                path_obj = await self.ratelimits.sleep(remove_prefix(self.api_base, url), method)
+            else:
+                time_to_sleep, path_obj = await self.ratelimits.check(remove_prefix(self.api_base, url), method)
+                if time_to_sleep > 0 and path_obj:
+                    raise Ratelimit(path_obj.path.name, path_obj.ratelimit_amount, path_obj.ratelimit_expires)
         logger.info("Making %s request to %s", method, url)
         resp = await self.session.request(method, url, headers=headers, json=json, **session_request_kwargs)
         if path_obj:
             path_obj.update(resp)
         do_retry = False
-        if resp.status == 401:  # Unauthorized
-            if self.session_token:  # Invalid session token
-                await self.get_session_token()
-                do_retry = True
-            elif self.username and self.password:  # Invalid refresh token
-                await self.login()
-                do_retry = True
-            else:
-                try:
-                    raise Unauthorized(url, resp)
-                finally:
-                    await resp.release()
-        if resp.status == 429:  # Ratelimit error. This should be handled by ratelimits but I'll handle it here as well.
-            if resp.headers.get("x-ratelimit-retry-after", ""):
-                await asyncio.sleep(
-                    (
+        if url.startswith(self.api_base):
+            if resp.status == 401:  # Unauthorized
+                if self.session_token:  # Invalid session token
+                    await self.get_session_token()
+                    do_retry = True
+                elif self.username and self.password:  # Invalid refresh token
+                    await self.login()
+                    do_retry = True
+                else:
+                    try:
+                        raise Unauthorized(method, url, resp)
+                    finally:
+                        await resp.release()
+            elif resp.status in [403, 412]:
+                site_key = resp.headers.get("X-Captcha-Sitekey", "")
+                if site_key:
+                    raise Captcha(site_key, method, url, resp)
+            elif resp.status == 429:  # Ratelimit error. This should be handled by ratelimits but I'll handle it here as
+                # well.
+                if resp.headers.get("x-ratelimit-retry-after", ""):
+                    diff = (
                         datetime.utcfromtimestamp(int(resp.headers["x-ratelimit-retry-after"])) - datetime.utcnow()
                     ).total_seconds()
-                )
-            else:
-                await asyncio.sleep(1)  # This is probably the result of multiple devices, so sleep for a second. Will
-                # give up on the 4th try though if it is persistent.
-            do_retry = True
+                    logger.warning("Sleeping for %s seconds.", diff)
+                    await asyncio.sleep(diff)
+                else:
+                    logger.warning("Sleeping for 1.25 seconds.")
+                    await asyncio.sleep(
+                        1.25
+                    )  # This is probably the result of multiple devices, so sleep for a second. Will
+                    # give up on the 4th try though if it is persistent.
+                do_retry = True
         if resp.status // 100 == 5:  # 5xx
             do_retry = True
         if do_retry:
@@ -288,6 +316,8 @@ class MangadexClient:
                 )
             else:
                 resp.raise_for_status()
+        elif not allow_non_successful_codes:
+            resp.raise_for_status()
         return resp
 
     async def _one_off(self, method, url, *, params=None, json=None, with_auth=True, retries=3, **kwargs):
@@ -298,13 +328,33 @@ class MangadexClient:
     async def _get_json(self, method, url, *, params=None, json=None, with_auth=True, retries=3, **kwargs):
         """Used for getting the json quickly when we don't care about request codes."""
         r = await self.request(method, url, params=params, json=json, with_auth=with_auth, retries=retries, **kwargs)
-        r.raise_for_status()
         json = await r.json()
         r.close()
         return json
 
     # Authentication
 
+    def raise_exception_if_not_authenticated(self, method: str, path: str):
+        """Raise an exception if authentication is missing. This is ideally used before making requests that will
+        always need authentication.
+
+        .. versionadded:: 0.5
+
+        :param method: The method to show.
+
+            .. seealso:: :attr:`.Unauthorized.method`.
+
+        :type method: str
+        :param path: The path to display.
+
+            .. seealso:: :attr:`.Unauthorized.path`.
+
+        :type path: str
+        :raises: :class:`.Unauthorized`
+        """
+        if self.anonymous_mode:
+            raise Unauthorized(method, path, None)
+
     @property
     def session_token(self) -> Optional[str]:
         """The session token tht the client has obtained. This will be None when the client is operating in anonymous
@@ -338,6 +388,8 @@ class MangadexClient:
         r.close()
         self.session_token = data["token"]["session"]
         self.refresh_token = data["token"]["refresh"]
+        if self.user.id == "client-user":
+            await self.user.fetch()
 
     async def login(self, username: Optional[str] = None, password: Optional[str] = None):
         """Logs in to the MangaDex API.
@@ -356,7 +408,7 @@ class MangadexClient:
             self.password = password
             self.anonymous_mode = False
         elif not (self.username and self.password):
-            raise Unauthorized(routes["login"], None)
+            self.raise_exception_if_not_authenticated("POST", routes["login"])
         r = await self.request(
             "POST", routes["login"], json={"username": self.username, "password": self.password}, with_auth=False
         )
@@ -364,14 +416,32 @@ class MangadexClient:
         r.close()
         self.session_token = data["token"]["session"]
         self.refresh_token = data["token"]["refresh"]
+        await self.user.fetch()
 
-    async def logout(self):
-        """Log out from the API. If a refresh token exists, calls the logout route on the API. The username and
-        password are cleared, and the client is put into anonymous mode."""
-        if self.refresh_token or self.session_token:
+    async def logout(self, delete_tokens: bool = True, clear_login_info: bool = True):
+        """Log out from the API.
+
+        :param delete_tokens: Whether or not to delete the refresh/session tokens by calling the logout endpoint.
+            Defaults to true.
+
+            .. versionadded:: 0.5
+
+        :type delete_tokens: bool
+        :param clear_login_info: Whether or not to clear login info from the client, so that future logins are not
+            possible without a new token or calling :meth:`.login` with the ``username`` and ``password`` parameters.
+            Defaults to true.
+
+            .. versionadded:: 0.5
+
+        :type clear_login_info: bool
+        """
+        if (self.refresh_token or self.session_token) and delete_tokens:
             (await self.request("POST", routes["logout"])).release()
-        self.username = self.password = self.refresh_token = self.session_token = None
-        self.anonymous_mode = True
+            self.refresh_token = self.session_token = None
+        if clear_login_info:
+            self.username = self.password = self.refresh_token = self.session_token = None
+            self.anonymous_mode = True
+            self.user = ClientUser(self)
 
     # Methods to get models
 
@@ -531,13 +601,19 @@ class MangadexClient:
 
         .. versionadded:: 0.3
 
+        .. deprecated:: 0.5
+            Use :attr:`.user` and :meth:`.ClientUser.fetch_user`
+
         :return: A :class:`.User` object.
         :rtype: User
         """
-        r = await self.request("GET", routes["logged_in_user"])
-        json = await r.json()
-        r.close()
-        return User(self, data=json)
+        warnings.warn(
+            "MangadexClient.logged_in_user is deprecated. Use MangadexClient.user and " "ClientUser.fetch_user().",
+            category=DeprecationWarning,
+            stacklevel=2,
+        )
+        await self.user.fetch_user()
+        return self.user
 
     def get_group(self, id: str) -> Group:
         """Get a group using it's ID.
@@ -555,9 +631,27 @@ class MangadexClient:
         """
         return Group(self, id=id)
 
+    def get_list(self, id: str) -> CustomList:
+        """Get a custom list using it's ID.
+
+        .. versionadded:: 0.5
+
+        .. warning::
+            This method returns a **lazy** CustomList instance. Call :meth:`.CustomList.fetch` on the returned object
+            to see
+            any values.
+
+        :param id: The custom list's UUID.
+        :type id: str
+        :return: A :class:`.CustomList` object.
+        :rtype: CustomList
+        """
+        return CustomList(self, id=id)
+
     # Batch models
 
-    async def _do_batch(self, items: Tuple[Model, ...], route_name: str):
+    async def _do_batch(self, items: Tuple[Model, ...], permission: str, route_name: str):
+        self.user.permission_exception(permission, "GET", routes[route_name])
         uuid_map: Dict[str, List[Model]] = {}
         for item in items:
             uuid_map.setdefault(item.id, []).append(item)
@@ -582,26 +676,29 @@ class MangadexClient:
 
     async def batch_authors(self, *authors: Author):
         """Updates a lot of authors at once, reducing the time needed to update tens or hundreds of authors.
+        |permission| ``author.list``
 
         .. versionadded:: 0.2
 
         :param authors: A tuple of all the authors (and artists) to update.
         :type authors: Tuple[Author, ...]
         """
-        await self._do_batch(authors, "author_list")
+        await self._do_batch(authors, "author.list", "author_list")
 
     async def batch_mangas(self, *mangas: Manga):
         """Updates a lot of mangas at once, reducing the time needed to update tens or hundreds of mangas.
+        |permission| ``manga.list``
 
         .. versionadded:: 0.2
 
         :param mangas: A tuple of all the mangas to update.
         :type mangas: Tuple[Manga, ...]
         """
-        await self._do_batch(mangas, "search")
+        await self._do_batch(mangas, "manga.list", "search")
 
     async def batch_chapters(self, *chapters: Chapter):
         """Updates a lot of chapters at once, reducing the time needed to update tens or hundreds of chapters.
+        |permission| ``chapter.list``
 
         .. versionadded:: 0.3
 
@@ -610,17 +707,40 @@ class MangadexClient:
         :param chapters: A tuple of all the chapters to update.
         :type chapters: Tuple[Chapter, ...]
         """
-        await self._do_batch(chapters, "chapter_list")
+        await self._do_batch(chapters, "chapter.list", "chapter_list")
 
     async def batch_groups(self, *groups: Group):
         """Updates a lot of groups at once, reducing the time needed to update tens or hundreds of groups.
+        |permission| ``scanlation_group.list``
 
         .. versionadded:: 0.3
 
         :param groups: A tuple of all the groups to update.
         :type groups: Tuple[Group, ...]
         """
-        await self._do_batch(groups, "group_list")
+        await self._do_batch(groups, "scanlation_group.list", "group_list")
+
+    async def batch_manga_read(self, *mangas: Manga):
+        """Find the read status for multiple mangas. |auth|
+
+        .. versionadded:: 0.5
+
+        :param mangas: A tuple of manga objects.
+        :type mangas: Tuple[Manga, ...]
+        """
+        # We can't use _do_batch here unfortunately.
+        self.raise_exception_if_not_authenticated("GET", routes["batch_manga_read"])
+        final_data = []
+        manga_list = list({manga.id for manga in mangas})
+        while manga_list:
+            batch = manga_list[:100]
+            manga_list = manga_list[100:]
+            r = await self.request("GET", routes["batch_manga_read"], params={"ids": batch})
+            json = await r.json()
+            r.close()
+            final_data.extend(json["data"])
+        for item in mangas:
+            item.chapters._update_read_data({"data": final_data})
 
     # Get lists
 
@@ -635,7 +755,7 @@ class MangadexClient:
     def get_groups(
         self, *, name: Optional[str] = None, order: Optional[GroupListOrder] = None, limit: Optional[int] = None
     ) -> Pager[Group]:
-        """Creates a :class:`.Pager` for groups.
+        """Creates a :class:`.Pager` for groups. |permission| ``scanlation_group.list``
 
         .. versionadded:: 0.4
 
@@ -664,6 +784,7 @@ class MangadexClient:
         if name:
             params["name"] = name.replace(" ", "+")
         self._add_order(params, order)
+        self.user.permission_exception("scanlation_group.list", "GET", routes["group_list"])
         return Pager(routes["group_list"], Group, self, params=params, limit=limit)
 
     def get_chapters(
@@ -682,7 +803,7 @@ class MangadexClient:
         order: Optional[ChapterListOrder] = None,
         limit: Optional[int] = None,
     ) -> Pager[Chapter]:
-        """Gets a :class:`.Pager` of chapters.
+        """Gets a :class:`.Pager` of chapters. |permission| ``chapter.list``
 
         .. versionadded:: 0.4
 
@@ -769,12 +890,13 @@ class MangadexClient:
         if published_after:
             params["publishAtSince"] = return_date_string(published_after)
         self._add_order(params, order)
+        self.user.permission_exception("chapter.list", "GET", routes["chapter_list"])
         return Pager(routes["chapter_list"], Chapter, self, params=params, limit=limit)
 
     def get_authors(
         self, *, name: Optional[str] = None, order: Optional[AuthorListOrder] = None, limit: Optional[int] = None
     ) -> Pager[Author]:
-        """Creates a :class:`.Pager` for authors.
+        """Creates a :class:`.Pager` for authors. |permission| ``author.list``
 
         .. versionadded:: 0.4
 
@@ -803,6 +925,7 @@ class MangadexClient:
         if name:
             params["name"] = name.replace(" ", "+")
         self._add_order(params, order)
+        self.user.permission_exception("author.list", "GET", routes["author_list"])
         return Pager(routes["author_list"], Author, self, params=params, limit=limit)
 
     def get_mangas(
@@ -825,7 +948,7 @@ class MangadexClient:
         order: Optional[MangaListOrder] = None,
         limit: Optional[int] = None,
     ) -> Pager[Manga]:
-        """Gets a :class:`.Pager` of mangas.
+        """Gets a :class:`.Pager` of mangas. |permission| ``manga.list``
 
         .. versionadded:: 0.4
 
@@ -915,11 +1038,272 @@ class MangadexClient:
         if updated_after:
             params["updatedAtSince"] = return_date_string(updated_after)
         self._add_order(params, order)
+        self.user.permission_exception("manga.list", "GET", routes["search"])
         return Pager(routes["search"], Manga, self, params=params, limit=limit)
 
     search = get_mangas
     """Alias for :meth:`.get_mangas`."""
 
+    # Create methods
+
+    async def create_author(self, name: str) -> Author:
+        """Create a new author. |auth| |permission| ``author.create``
+
+        .. versionadded:: 0.5
+
+        :param name: The author's name.
+        :type name: str
+        :return: The new author.
+        :rtype: Author
+        """
+        params = {"name": name}
+        self.raise_exception_if_not_authenticated("POST", routes["author_list"])
+        self.user.permission_exception("author.create", "POST", routes["author_list"])
+        r = await self.request("POST", routes["author_list"], json=params)
+        json = await r.json()
+        r.close()
+        return Author(self, data=json)
+
+    async def create_group(self, name: str, members: Optional[List[User]], *, leader: Optional[User] = None) -> Group:
+        """Create a scanlation group. |auth| |permission| ``scanlation_group.create``
+
+        .. versionadded:: 0.5
+
+        :param name: The name of the group.
+        :type name: str
+        :param members: The members of the group.
+        :type members: List[User]
+        :param leader: The leader of the group. Defaults to the logged in user.
+        :type leader: User
+        :return: A new group.
+        :rtype: Group
+        """
+        leader = leader or self.user
+        params = {"name": name, "members": [item.id for item in members], "leader": leader.id}
+        self.raise_exception_if_not_authenticated("POST", routes["group_list"])
+        self.user.permission_exception("scanlation_group.create", "POST", routes["group_list"])
+        r = await self.request("POST", routes["group_list"], json=params)
+        json = await r.json()
+        r.close()
+        return Group(self, data=json)
+
+    async def create_manga(
+        self,
+        *,
+        title: Optional[Dict[str, str]] = None,
+        alt_titles: Optional[List[Dict[str, str]]] = None,
+        descriptions: Optional[Dict[str, str]] = None,
+        authors: Optional[List[Union[str, Author]]] = None,
+        artists: Optional[List[Union[str, Author]]] = None,
+        links: Optional[MangaLinks] = None,
+        language: Optional[str] = None,
+        last_volume: Optional[str] = None,
+        last_chapter_number: Optional[str] = None,
+        demographic: Optional[Demographic] = None,
+        status: Optional[MangaStatus] = None,
+        year: Optional[int] = None,
+        rating: Optional[ContentRating] = None,
+        notes: Optional[str] = None,
+        all_titles: Optional[Dict[str, TitleList]] = None,
+    ) -> Manga:
+        """Create a manga. |auth| |permission| ``manga.create``
+
+        .. versionadded:: 0.5
+
+        .. note::
+            New mangas have to be approved by the mod team.
+
+        :param title: The titles of the manga.
+
+            .. note::
+                See the documentation for the ``all_titles`` parameter to learn how to add all titles in one dictionary.
+
+        :type title: Dict[str, str]
+        :param alt_titles: Alternate titles to use.
+        :type alt_titles: List[Dict[str, str]]
+        :param all_titles: A dictionary of a language code key and a :class:`.TitleList` as values.
+
+            .. warning:: Using ``title`` and ``all_titles`` will overwrite any values in the dictionary provided to
+                ``title`` if a corresponding title for the same language code is found in ``all_titles``.
+
+            .. admonition:: Using ``all_titles`` to set titles:
+
+                .. code-block:: python
+
+                    from asyncdex import AttrDict, TitleList
+
+                    titles_en = ["Primary", "secondary", "tertiary"]
+                    titles_es = ["Primero, "segundo"]
+                    title_dict = AttrDict()
+                    title_dict["en"] = TitleList(titles_en)
+                    title_dict["es"] = TitleList(titles_es)
+
+                    manga = await client.create_manga(..., all_titles=title_dict)
+
+        :type all_titles: Dict[str, TitleList]
+        :param descriptions: A dictionary of language codes to descriptions for that language.
+        :type descriptions: Dict[str, str]
+        :param authors: A list of either :class:`.Author` objects or author UUIDs.
+        :type authors: List[Author]
+        :param artists: A list of either :class:`.Author` objects or author UUIDs.
+        :type artists: List[Author]
+        :param links: An instance of :class:`.MangaLinks` containing the IDs for the manga.
+        :type links: MangaLinks
+        :param language: The original language of the manga.
+        :type language: str
+        :param last_volume: The number of the last volume.
+        :type last_volume: str
+        :param last_chapter_number: The number of the last chapter.
+        :type last_chapter_number: str
+        :param demographic: The manga's demographic, or ``None`` to have no demographic.
+        :type demographic: Optional[Demographic]
+        :param status: The manga's status, or ``None`` to have no status.
+        :type status: Optional[MangaStatus]
+        :param year: The year the manga started publication.
+        :type year: int
+        :param rating: The manga's content rating, or ``None`` to use the default.
+        :type rating: Optional[CotentRating]
+        :param notes: Optional notes to show to a moderator.
+        :type notes: str
+        :raise: :class:`ValueError` if the ``title`` field is None.
+        :return: The new manga.
+        :rtype: Manga
+        """
+        title = title or {}
+        alt_titles = alt_titles or []
+        all_titles = all_titles or {}
+        for lang, titles in all_titles.items():
+            primary, alternates = titles.parts()
+            title[lang] = primary
+            for item in alternates:
+                alt_titles.append({lang: item})
+        if not title:
+            raise ValueError("A title needs to be specified.")
+        params = {
+            "title": title,
+            "lastVolume": last_volume,
+            "lastChapter": last_chapter_number,
+            "publicationDemographic": demographic.value if demographic else None,
+            "status": status.value if status else None,
+            "contentRating": rating.value if rating else None,
+            "modNotes": notes,
+        }
+        if alt_titles:
+            params["altTitles"] = alt_titles
+        if descriptions:
+            params["description"] = descriptions
+        if authors:
+            params["authors"] = [str(item) for item in authors]
+        if artists:
+            params["artists"] = [str(item) for item in artists]
+        if links:
+            params["links"] = links.to_dict()
+        if language:
+            params["originalLanguage"] = language
+        if year:
+            params["year"] = year
+        self.raise_exception_if_not_authenticated("POST", routes["search"])
+        self.user.permission_exception("manga.create", "POST", routes["search"])
+        r = await self.request("POST", routes["search"], json=params)
+        json = await r.json()
+        r.close()
+        return Manga(self, data=json)
+
+    # Account methods
+
+    async def create(
+        self, username: str, password: str, email: str, login: bool = True, store_credentials: bool = True
+    ):
+        """Create an account.
+
+        .. versionadded:: 0.5
+
+        :param username: The username of the account.
+        :type username: str
+        :param password: The password of the account.
+        :type password: str
+        :param email: The email of the account.
+        :type email: str
+        :param login: Whether or not to log in to the API using the new account credentials. Defaults to ``True``.
+        :type login: bool
+        :param store_credentials: Whether or not to store the credentials inside the client class. Defaults to ``True``.
+
+            .. note::
+                If the credentials are not stored but ``login`` is True, then the client will operate in refresh
+                token only mode.
+        :type store_credentials: bool
+        """
+        await self.request(
+            "POST",
+            routes["create_account"],
+            json={"username": username, "password": password, "email": email},
+            with_auth=False,
+        )
+        if login:
+            await self.login(username, password)
+            if not store_credentials:
+                self.username = self.password = None
+        elif store_credentials:
+            self.username = username
+            self.password = password
+
+    async def activate_account(self, code: str):
+        """Activate a MangaDex account.
+
+        .. versionadded:: 0.5
+
+        :param code: The code to activate.
+        :type code: str
+        """
+        await self.request("GET", routes["activate_account"].format(code=code), with_auth=False)
+
+    async def resend_activation_code(self, email: str):
+        """Resend an activation email.
+
+        .. versionadded:: 0.5
+
+        :param email: The email to resend to
+        :type email: str
+        """
+        await self.request("POST", routes["resend"], json={"email": email}, with_auth=False)
+
+    async def reset_password_email(self, email: str):
+        """Start the process of resetting an account's password.
+
+        .. versionadded:: 0.5
+
+        :param email: The email of the account to reset the password of.
+        :type email: str
+        """
+        await self.request("POST", routes["start_recover"], json={"email": email}, with_auth=False)
+
+    async def finish_password_reset(self, code: str, new_password: str, store_new_password: bool = True):
+        """Finish the password reset process.
+
+        .. versionadded:: 0.5
+
+        .. warning::
+            The MangaDex API fails silently on password resets, meaning that if a password reset fails it will not
+            tell you. Instead, future login attempts will fail. You can check if a reset is valid by calling
+            :meth:`.login` with the username and new password. If it returns 401 then the password reset failed.
+
+        :param code: The code obtained from the sent email.
+        :type code: str
+        :param new_password: The new password to set. Needs to be >8 characters.
+        :type new_password: str
+        :param store_new_password: Whether or not to store the password in the client. The password will not be
+            stored if a corresponding username is not stored in the client class. Defaults to ``True``.
+        :type store_new_password: bool
+        :raises: :class:`ValueError` if the password is <8 characters.
+        """
+        if len(new_password) < 8:
+            raise ValueError("Password must be >=8 characters.")
+        await self.request(
+            "POST", routes["finish_recover"].format(code=code), json={"newPassword": new_password}, with_auth=False
+        )
+        if store_new_password and self.username:
+            self.password = new_password
+
     # Misc methods
 
     async def ping(self):
@@ -930,6 +1314,23 @@ class MangadexClient:
         """
         return await self._one_off("GET", routes["ping"])
 
+    async def solve_captcha(self, answer: str):
+        """Solve the captcha.
+
+        .. versionadded:: 0.5
+
+        :param answer: The answer to the captcha.
+        :type answer: str
+        :raises: :class:`.InvalidCaptcha` if the captcha is invalid.
+        """
+        r = await self.request(
+            "POST", routes["captcha"], json={"captchaChallenge": answer}, allow_non_successful_codes=True
+        )
+        if not r.ok:
+            raise InvalidCaptcha(r)
+        else:
+            r.close()
+
     async def convert_legacy(self, model: Type[_LegacyModelT], ids: List[int]) -> Dict[int, _LegacyModelT]:
         """Convert a list of legacy IDs to the new UUID system.
 
@@ -980,7 +1381,7 @@ class MangadexClient:
 
         .. versionadded:: 0.4
 
-        .. seealso:: :meth:`.Client.get_page`, which will automatically call this method for you.
+        .. seealso:: :meth:`.MangadexClient.get_page`, which will automatically call this method for you.
 
         :param url: The URL of the image.
         :type url: str
@@ -994,7 +1395,7 @@ class MangadexClient:
         :param cached: Whether or not the request was cached (The ``X-Cache`` header starting with the value ``HIT``).
         :type cached: bool
         """
-        await self.request(
+        r = await self.request(
             "POST",
             routes["report_page"],
             json={
@@ -1005,6 +1406,7 @@ class MangadexClient:
                 "cached": cached,
             },
         )
+        r.close()
 
     async def get_page(self, url: str) -> aiohttp.ClientResponse:
         """A method to download one page of a chapter, using the URLs from :meth:`.pages`. This method is more
@@ -1019,7 +1421,7 @@ class MangadexClient:
         """
         start = datetime.utcnow()
         try:
-            r = await self.request("GET", url)
+            r = await self.request("GET", url, retries=1)
             content_length = len(await r.read())
         except Exception:
             success = False
@@ -1029,12 +1431,16 @@ class MangadexClient:
         else:
             success = r.ok and "image" in r.headers.get("Content-Type", "")
             cached = r.headers.get("X-Cache", "").lower().startswith("hit")
-            r.raise_for_status()
             return r
         finally:
             finish = datetime.utcnow()
             time_difference = int((finish - start).total_seconds() * 1000)
-            asyncio.create_task(self.report_page(url, success, content_length, time_difference, cached))  # NOQA
+            try:
+                await asyncio.create_task(
+                    self.report_page(url, success, content_length, time_difference, cached)
+                )  # NOQA
+            except Exception:
+                pass
 
     async def close(self):
         """Close the client.
