@@ -3,6 +3,8 @@ from typing import Optional, TYPE_CHECKING, Type
 
 import aiohttp
 
+from .constants import routes
+
 if TYPE_CHECKING:
     from .models.abc import Model
 
@@ -35,14 +37,27 @@ class Ratelimit(AsyncDexException):
 class HTTPException(AsyncDexException):
     """Exceptions for HTTP status codes."""
 
+    method: str
+    """The HTTP method that caused the exception.
+    
+    .. versionadded:: 0.5
+    """
+
     path: str
     """The URL taken that hit the error."""
 
     response: aiohttp.ClientResponse
     """The :class:`aiohttp.ClientResponse` object from the request."""
 
-    def __init__(self, path: str, response: aiohttp.ClientResponse):
-        super().__init__(f"HTTP Error on {path}.")
+    def __init__(
+        self,
+        method: str,
+        path: str,
+        response: aiohttp.ClientResponse,
+        *,
+        msg: str = "HTTP Error on {method} for {path}.",
+    ):
+        super().__init__(msg.format(**locals()))
         self.path = path
         self.response = response
 
@@ -55,10 +70,8 @@ class Unauthorized(HTTPException):
     """The :class:`aiohttp.ClientResponse` object from the request. May be ``None`` if a user tries to login without 
     stored credentials."""
 
-    def __init__(self, path: str, response: Optional[aiohttp.ClientResponse]):
-        AsyncDexException.__init__(self, f"Unauthorized for path {path}.")
-        self.path = path
-        self.response = response
+    def __init__(self, method: str, path: str, response: Optional[aiohttp.ClientResponse]):
+        super().__init__(method, path, response, msg="Unauthorized for {method} on {path}.")
 
 
 class Missing(AsyncDexException):
@@ -98,3 +111,57 @@ class InvalidID(AsyncDexException):
         super().__init__(f"There is no {model.__name__} with the UUID {id!r}.")
         self.id = id
         self.model = model
+
+
+class PermissionMismatch(HTTPException):
+    """An exception raised if the current user does not have a certain permission.
+
+    .. versionadded:: 0.5
+    """
+
+    permission: str
+    """The permission node the user is lacking."""
+
+    response: Optional[aiohttp.ClientResponse]
+    """The :class:`aiohttp.ClientResponse` object from the request. May be ``None`` if a user tries to login without 
+    stored credentials."""
+
+    def __init__(self, permission: str, method: str, path: str, response: Optional[aiohttp.ClientResponse]):
+        super().__init__(method, path, response, msg="Missing permission %s for {method} on {path}." % permission)
+        self.permission = permission
+
+
+class Captcha(HTTPException):
+    """An exception raised if a captcha solve is required to proceed.
+
+    .. versionadded:: 0.5
+
+    .. admonition:: Solving reCaptchas with AsyncDex:
+
+        AsyncDex will raise the Captcha exception to any request that prompts for a captcha. Afterwards,
+        it is necessary to call :meth:`.solve_captcha` with the correct captcha response, and then retry whatever
+        request caused the captcha.
+    """
+
+    site_key: str
+    """The captcha sitekey to solve."""
+
+    def __init__(
+        self,
+        site_key: str,
+        method: str,
+        path: str,
+        response: aiohttp.ClientResponse,
+    ):
+        super().__init__(method, path, response, msg="Captcha required for {method} on {path}")
+        self.site_key = site_key
+
+
+class InvalidCaptcha(HTTPException):
+    """An exception raised if an attempt to solve a captcha was invalid.
+
+    .. versionadded:: 0.5
+    """
+
+    def __init__(self, response: aiohttp.ClientResponse):
+        super().__init__("POST", routes["captcha"], response, msg="Invalid captcha solve.")
